"""This module is used to parse PDF for expert reports.
"""
from collections import defaultdict
import os
import tika
from tika import parser
import pandas as pd
from pandas import DataFrame
from utils import (
    plaintiff_extraction,
    defendent_extraction,
    case_number_extraction,
    patent_extraction,
    email_extraction,
    address_extraction,
)


tika.initVM()


def main(path: str) -> DataFrame:
    """
    The functions iterates through all the given files and gathers the data in the \
    form of a dataframe
    """
    data = defaultdict(list)
    required_files = [file for file in os.listdir(path) if file.find(".pdf") != -1]
    for file in required_files:
        print(file)
        content = parser.from_file(file)["content"]
        data["file"].append(file)
        data["email"].append(email_extraction(content))
        data["plaintiff"].append(plaintiff_extraction(content))
        data["defendant"].append(defendent_extraction(content))
        data["case_number"].append(case_number_extraction(content))
        data["patents"].append(patent_extraction(content))
        data["address"].append(address_extraction(content))

    data_expert = pd.DataFrame(data)
    data_expert.to_csv("required_data.csv")
    return data_expert


if __name__ == "__main__":
    HOME_DIR = os.path.expanduser("~")
    BASE_DIR = "Code/pdf_parser/server_documents/preliminary_response"
    PATH = os.path.join(HOME_DIR, BASE_DIR)
    print(main(PATH))
